@@ -14,11 +14,11 @@
 
 from __future__ import annotations
 
-from typing import Optional
+from typing import Optional, Union
 
 from google.adk.agents import LlmAgent, RunConfig
 from google.adk.agents.base_agent import BaseAgent
-from google.adk.agents.llm_agent import ToolUnion
+from google.adk.agents.llm_agent import InstructionProvider, ToolUnion
 from google.adk.agents.run_config import StreamingMode
 from google.adk.models.lite_llm import LiteLlm
 from google.adk.runners import Runner
@@ -26,11 +26,9 @@ from google.genai import types
 from pydantic import ConfigDict, Field
 from typing_extensions import Any
 
-from veadk.config import getenv
+from veadk.config import settings
 from veadk.consts import (
-    DEFAULT_MODEL_AGENT_API_BASE,
-    DEFAULT_MODEL_AGENT_NAME,
-    DEFAULT_MODEL_AGENT_PROVIDER,
+    DEFAULT_AGENT_NAME,
     DEFAULT_MODEL_EXTRA_CONFIG,
 )
 from veadk.evaluation import EvalSetRecorder
@@ -53,25 +51,25 @@ class Agent(LlmAgent):
     model_config = ConfigDict(arbitrary_types_allowed=True, extra="allow")
     """The model config"""
 
-    name: str = "veAgent"
+    name: str = DEFAULT_AGENT_NAME
     """The name of the agent."""
 
     description: str = DEFAULT_DESCRIPTION
     """The description of the agent. This will be helpful in A2A scenario."""
 
-    instruction: str = DEFAULT_INSTRUCTION
-    """The instruction for the agent, such as principles of function calling."""
+    instruction: Union[str, InstructionProvider] = DEFAULT_INSTRUCTION
+    """The instruction for the agent."""
 
-    model_name: str = getenv("MODEL_AGENT_NAME", DEFAULT_MODEL_AGENT_NAME)
+    model_name: str = Field(default_factory=lambda: settings.model.name)
     """The name of the model for agent running."""
 
-    model_provider: str = getenv("MODEL_AGENT_PROVIDER", DEFAULT_MODEL_AGENT_PROVIDER)
+    model_provider: str = Field(default_factory=lambda: settings.model.provider)
     """The provider of the model for agent running."""
 
-    model_api_base: str = getenv("MODEL_AGENT_API_BASE", DEFAULT_MODEL_AGENT_API_BASE)
+    model_api_base: str = Field(default_factory=lambda: settings.model.api_base)
     """The api base of the model for agent running."""
 
-    model_api_key: str = Field(default_factory=lambda: getenv("MODEL_AGENT_API_KEY"))
+    model_api_key: str = Field(default_factory=lambda: settings.model.api_key)
     """The api key of the model for agent running."""
 
     model_extra_config: dict = Field(default_factory=dict)
@@ -95,9 +93,6 @@ class Agent(LlmAgent):
     tracers: list[BaseTracer] = []
     """The tracers provided to agent."""
 
-    serve_url: str = ""
-    """The url of agent serving host. Show in agent card."""
-
     def model_post_init(self, __context: Any) -> None:
         super().model_post_init(None)  # for sub_agents init
 
@@ -201,7 +196,6 @@ class Agent(LlmAgent):
         collect_runtime_data: bool = False,
         eval_set_id: str = "",
         save_session_to_memory: bool = False,
-        enable_memory_optimization: bool = False,
     ):
         """Running the agent. The runner and session service will be created automatically.
 
@@ -231,7 +225,6 @@ class Agent(LlmAgent):
         # memory service
         short_term_memory = ShortTermMemory(
             backend="database" if load_history_sessions_from_db else "local",
-            enable_memory_optimization=enable_memory_optimization,
             db_url=db_url,
         )
         session_service = short_term_memory.session_service
