@@ -14,9 +14,11 @@
 
 import time
 
-from veadk.config import getenv
+from veadk.utils.misc import getenv
 from veadk.version import VERSION
 
+DEFAULT_AGENT_NAME = "veAgent"
+
 DEFAULT_MODEL_AGENT_NAME = "doubao-seed-1-6-250615"
 DEFAULT_MODEL_AGENT_PROVIDER = "openai"
 DEFAULT_MODEL_AGENT_API_BASE = "https://ark.cn-beijing.volces.com/api/v3/"
@@ -30,6 +32,9 @@ DEFAULT_MODEL_EXTRA_CONFIG = {
         "caching": {
             "type": getenv("MODEL_AGENT_CACHING", "enabled"),
         },
+        # "thinking": {
+        #     "type": "disabled"
+        # },
         "expire_at": int(time.time()) + 3600,  # expire after 1 hour
     },
 }
@@ -47,3 +52,10 @@ DEFAULT_TLS_OTEL_EXPORTER_REGION = "cn-beijing"
 DEFAULT_CR_INSTANCE_NAME = "veadk-user-instance"
 DEFAULT_CR_NAMESPACE_NAME = "veadk-user-namespace"
 DEFAULT_CR_REPO_NAME = "veadk-user-repo"
+
+DEFAULT_TLS_LOG_PROJECT_NAME = "veadk-logs"
+DEFAULT_TLS_TRACING_INSTANCE_NAME = "veadk-tracing"
+
+DEFAULT_TOS_BUCKET_NAME = "ark-tutorial"
+
+DEFAULT_COZELOOP_SPACE_NAME = "VeADK Space"
