@@ -244,8 +244,26 @@ def llm_gen_ai_messages(params: LLMAttributesParams) -> ExtractorResponse:
                                     )
                             if part.inline_data:
                                 if len(content.parts) == 1:
-                                    # TODO(qingliang)
-                                    pass
+                                    part = content.parts[0]
+                                    user_event["gen_ai.user.message"].update(
+                                        {
+                                            "parts.0.type": "image_url",
+                                            "parts.0.image_url.name": (
+                                                part.inline_data.display_name.split(
+                                                    "/"
+                                                )[-1]
+                                                if part.inline_data
+                                                and part.inline_data.display_name
+                                                else "<unknown_image_name>"
+                                            ),
+                                            "parts.0.image_url.url": (
+                                                part.inline_data.display_name
+                                                if part.inline_data
+                                                and part.inline_data.display_name
+                                                else "<unknown_image_url>"
+                                            ),
+                                        }
+                                    )
                                 else:
                                     user_event["gen_ai.user.message"].update(
                                         {
